#
# spec file for package neard
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010-2012 B1 Systems GmbH, Vohburg, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           neard
Version:        0.19
Release:        1.5
Summary:        NFC for Linux
License:        GPL-2.0-only
Group:          Hardware/Mobile
URL:            https://github.com/linux-nfc/neard
#Git-Clone:     https://git.kernel.org/pub/scm/network/nfc/neard.git/
Source:         https://git.kernel.org/pub/scm/network/nfc/neard.git/snapshot/%name-%version.tar.gz
Source1:        neard.service
Source2:        99-neard.rules
Patch1:         neard-0.13-fix-dbus_send_destination_config.patch
Patch2:         harden_neard.service.patch
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  check-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1) >= 1.4
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  pkgconfig(libnl-genl-3.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(systemd)
# -test subpackage was dropped (boo#1219314)
Obsoletes:      neard-test <= %{version}
%{?systemd_ordering}

%description
NFC support for Linux.

%package devel
Summary:        Files needed for NFC development
Group:          Development/Sources

%description devel
Files needed to develop applications for the NFC stack.

%package test
Summary:        Files needed for NFC development
Group:          Development/Tools/Debuggers
Requires:       neard

%description test
Files needed to test applications for the NFC stack.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
		--enable-tools \
		--disable-test

%make_build all

%install
%make_install
install --mode=0644 -D %{SOURCE1} %{buildroot}%{_unitdir}/neard.service
install --mode=0644 -D %{SOURCE2} %{buildroot}%{_prefix}/lib/udev/rules.d/99-neard.rules
perl -i -lpe 's{^#!/usr/bin/env }{#!/usr/bin/}' \
	"%buildroot/%_libdir/neard/test/phdc-simple-manager"
# add missing shebang line to soothe rpmlint
perl -i -lpe 's{^}{#!/usr/bin/python\n} if $.==1' \
	"%buildroot/%_libdir/neard/test/neardutils.py"

%pre
%service_add_pre neard.service

%preun
%service_del_preun neard.service

%postun
%service_del_postun neard.service

%post
%service_add_post neard.service

%files
%license COPYING
%doc AUTHORS ChangeLog README
%config %{_sysconfdir}/dbus-1/system.d/org.neard.conf
%dir %{_libexecdir}/nfc/
%{_libexecdir}/nfc/neard
%{_prefix}/lib/udev/rules.d/99-neard.rules
%{_unitdir}/neard.service
%{_bindir}/nciattach
%{_bindir}/nfctool
%{_mandir}/man1/nfctool.1%{?ext_man}
%{_mandir}/man5/neard.conf.5%{?ext_man}
%{_mandir}/man8/neard.8%{?ext_man}

%files devel
%{_includedir}/near/
%{_includedir}/version.h
%{_libdir}/pkgconfig/neard.pc

%changelog
* Thu Feb 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop python2-based test/example script (neard-test package):
  + Pass --disable test to configure
  + Drop neard-test subpackage (obsoleted by main package)
  + Addresses boo#1219314.
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.19:
  * Fixed missing DBus org.neard.se.conf.
  * Sync Linux kernel UAPI nfc.h header with newer kernel.
  * NFC tag: Implement readout of tag UID via DBus interface.
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to release 0.18:
  * Fixed configure with newer autoconf v2.71.
  * Made missing autoconf-archive messages nicer.
  * Fixed minor uninitialized access reported by Valgrind.
* Wed Oct 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.17
  * Fix some memory leaks and double frees.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Mon Oct 11 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_neard.service.patch
  Modified:
  * neard.service
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.16:
  * Added NDEF multi-record write support.
  * Added ST Type5 tags support.
  * Added nciattach tool for NCI UART configuration.
  * Added support for NFC_CMD_ACTIVATE_TARGET.
  * Added NDEF MIME payload exposure.
  * Fixed Mifare Ultralight C issue.
  * Fixed ACE starting logic.
  * Fixed an NDEF segmentation fault.
  * Fixed nfctool -d command line option handling.
  * Fixed several secure elements related bugs.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through the -mini flavors.
* Fri Mar  6 2015 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) in place of systemd-devel: the
  smaller dependency is perfectly sufficient for this package.
* Thu Mar  5 2015 p.drouand@gmail.com
- Update to version 0.15
  * Added iso15693 (NFC type5) support.
  * Added Secure Element support (seeld).
  * Added iso14443-B (NFC type4b) support.
  * Added NFC type5 RMB (Read Multiple Block) support.
  * Fixed NFC type1 dynamic read.
  * Fixed NFC type1 check_presence to only read the tag ID.
  * Fixed NFC type2 CC magic number check.
  * Fixed NFC type4 NDEF detection and handling code.
  * Fixed NFC type4 check_presence implementation.
  * Fixed PHDC coding style and potential bugs.
  * Fixed the constant poll loop to retry on busy adapters.
  * Fixed an agent memory leak.
  * Fixed and cleaned the build system.
- Remove obsolete macros
* Tue Jun 10 2014 acho@susue.com
- Move nfctool from neard-test to neard and neard-test Require neard.
  (bnc#881554)
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Sun Feb  2 2014 jengelh@inai.de
- Use libnl3 instead of libnl1
- Remove redundant %%clean section, more robust make install call,
  and a simplified file list
* Wed Jan 22 2014 acho@suse.com
- add %%doc AUTHORS COPYING ChangeLog README
* Fri Jan 17 2014 acho@suse.com
- Remove Unnecessary BuildRequires:  systemd and systemd-devel.
* Thu Jan 16 2014 acho@suse.com
- Clean empty %%post.(bnc#837978)
- Add 'send_destination' to org.neard.conf.(bnc#837978)
- Add 'ACTION=="add"' for udev rule.(bnc#837978)
* Wed Jan 15 2014 acho@suse.com
- use --prefix=%%_prefix, kill the %%clean section. kill has_systemd.
  (bnc#837978)
- add udev rules to enable this service by systemd.
- remove systemctl from %%post.
* Wed Dec 18 2013 cfarrell@suse.com
- license update: GPL-2.0
  majority of files have GPL-2.0 (only) license
* Tue Dec 17 2013 acho@suse.com
- Add neard.service to enable neard.(bnc#837978)
  Fixed systemd BuildRequires version.
* Fri Dec  6 2013 acho@suse.com
- Rmove neard-rpmlintrc.
  whitelist the "org.neard.conf" DBUS service.(bnc#837978)
* Thu Oct 24 2013 acho@suse.com
- Initial neard package - version 0.13 (fate#315616)
